﻿using System;
using System.ComponentModel;
using System.Globalization;
using System.Web.UI;

namespace ELTE.Web.GoogleStaticMap.Control
{
    /// <summary>
    /// Google földrajzi koordináta típusa.
    /// </summary>
    [Serializable] // szélializálhatóság jelzése
    [ToolboxItem(true)] // eszköztárelem
    [ToolboxData("<{0}:GoogleCoordinate Latitude=\"\" Longitude=\"\" runat=\"server></{0}:GoogleCoordinate>")] // kódmegfelelője a vezérlőnek
    public class GoogleCoordinate
    {
        /// <summary>
        /// Földrajzi hosszúság lekérdezése, vagy beállítása.
        /// </summary>
        [Bindable(true)] // használható-e az érték adattársításra
        [Category("Coordinate")] // a tulajdonság ablakban a megjelenítési kategória beállítása
        [DefaultValue("")] // alapértelmezett érték beállítása
        [Localizable(false)] // lokalizálható-e a tulajdonság
        public Double Longitude { get; set; }

        /// <summary>
        /// Földrajzi szélesség lekérdezése, vagy beállítása.
        /// </summary>
        [Bindable(true)]
        [Category("Coordinate")]
        [DefaultValue("")]
        [Localizable(false)]
        public Double Latitude { get; set; }

        public GoogleCoordinate() { }
        public GoogleCoordinate(Double latitude, Double longitude) { Latitude = latitude; Longitude = longitude; }

        public override String ToString()
        {
            return Latitude.ToString("F6", CultureInfo.CreateSpecificCulture("en-US")) + "," + Longitude.ToString("F6", CultureInfo.CreateSpecificCulture("en-US"));
            // a koordinátákat az angol nyelvi beállításoknak megfelelően alakítjuk át
        }
    }
}
