﻿using System;
using System.Linq;
using System.Web.UI.WebControls;
using System.Collections.Generic;

namespace ELTE.Web.TravelAgency
{
    public partial class RentAppartment : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            _DivRentMade.Visible = false; // az eredmény jelzőt nem mutatjuk

            if (Request.Cookies["Customer"] != null) // amennyiben van a felhasználónak sütije
            { 
                using (TravelAgencyEntities entities = new TravelAgencyEntities())
                {
                    String customerName = Request.Cookies["Customer"]["CustomerName"].ToString();
                    String customerPassword = Request.Cookies["Customer"]["CustomerPassword"].ToString();

                    Customer customer = entities.Customer
                                                .Where(x => x.UserName == customerName && x.UserPassword == customerPassword) // betöltjük a süti alapján a felhasználót
                                                .FirstOrDefault();

                    if (customer != null) // ammenyiben van találat
                    {
                        Session.Add("Customer", customer); // felvesszük a felhasználót a munkafolyamatba
                    }
                }

            }

            if (Session["Customer"] == null)
            {
                _DivLoginRequired.Visible = true;
                _ButtonRent.Visible = false;
            }
            else
            {
                _DivLoginRequired.Visible = false;
                _ButtonRent.Visible = true;
            }   

            if (String.IsNullOrEmpty(Request["Appartment"]))
                Response.Redirect("Default.aspx");
        }

        public void ValidatorRentTime_ServerValidate(object sender, ServerValidateEventArgs e)
        // az egyedi validátorhoz rendelt eseménykezelő
        {
            Int32 d;
            if (!String.IsNullOrEmpty(_TextRentTime.Text) && Int32.TryParse(e.Value, out d) && d >= 1) // ellenőrizzük, hogy az érték megfelelő-e
                e.IsValid = true;
            else
                e.IsValid = false;
        }

        public void ButtonCheckRentTime_Click(object sender, EventArgs e)
        {
            if (_CalendarStartTime.SelectedDate < DateTime.Now.AddDays(1)) // ellenőrizzük, hogy a kezdődátum megfelelő-e
            {
                _LabelCheckRentTime.Text = "A foglalást csak jövőbeli kezdettel végezhető!<br />";
                return;
            }

            Int32 d;
            if (String.IsNullOrEmpty(_TextRentTime.Text) || !Int32.TryParse(_TextRentTime.Text, out d) && d >= 1) // ellenőrizzük, hogy az érték megfelelő-e
            {
                _LabelCheckRentTime.Text = "Az időtartam csak pozitív szám lehet!<br />";
                return;
            }

            using (TravelAgencyEntities entities = new TravelAgencyEntities())
            {
                try
                {
                    // időintervallum ellenőrzése
                    Int32 appartmentId = Convert.ToInt32(Request["Appartment"]);
                    DateTime startTime = _CalendarStartTime.SelectedDate;
                    DateTime endTime = _CalendarStartTime.SelectedDate.AddDays(Convert.ToInt32(_TextRentTime.Text) * 7);

                    List<Rent> rentsList = entities.Rent.Where(x => x.AppartmentId == appartmentId).ToList();
                    // lekérjük az adott apartmanhoz tartozó foglalásokat

                    if (rentsList.Where(x => (x.StartDate <= startTime && startTime < x.StartDate.AddDays(x.Weeks * 7) ||
                                        x.StartDate < endTime && endTime <= x.StartDate.AddDays(x.Weeks * 7)) ||
                                        startTime < x.StartDate && x.StartDate.AddDays(x.Weeks * 7) < endTime).Count() > 0)
                    {
                        // ellenőrizzük, hogy az új dátumok nem ütköznek-e jelenlegi foglalásokkal
                        _LabelCheckRentTime.Text = "A megadott időben " + startTime.ToString("yyyy-MM-dd") + " - " + endTime.ToString("yyyy-MM-dd") + " a szállás foglalt, kérem válasszon más időpontot!";
                    }
                    else
                    {
                        _LabelCheckRentTime.Text = "A megjelölt időben (" + startTime.ToString("yyyy-MM-dd") + " - " + endTime.ToString("yyyy-MM-dd") + ") szabad a szállás!";
                    }
                }
                catch
                {
                    _LabelCheckRentTime.Text = "Az ellenőrzés során hiba lépett fel!";
                }
            }
        }

        public void ButtonRent_Click(object sender, EventArgs e)
        {
            if (_CalendarStartTime.SelectedDate < DateTime.Now.AddDays(1)) // ellenőrizzük, hogy a kezdődátum megfelelő-e
            {
                _ValidatorStartTime.IsValid = false;
                return;
            }
            else
                _ValidatorStartTime.IsValid = true;

            using (TravelAgencyEntities entities = new TravelAgencyEntities())
            {
                try
                {
                    Int32 appartmentId = Convert.ToInt32(Request["Appartment"]);
                    DateTime startTime = _CalendarStartTime.SelectedDate;
                    DateTime endTime = _CalendarStartTime.SelectedDate.AddDays(Convert.ToInt32(_TextRentTime.Text) * 7);

                    List<Rent> rentsList = entities.Rent.Where(x => x.AppartmentId == appartmentId).ToList();

                    if (rentsList.Where(x => (x.StartDate <= startTime && startTime < x.StartDate.AddDays(x.Weeks * 7) ||
                                              x.StartDate < endTime && endTime <= x.StartDate.AddDays(x.Weeks * 7)) ||
                                              startTime < x.StartDate && x.StartDate.AddDays(x.Weeks * 7) < endTime).Count() > 0)
                    {
                        _LabelCheckRentTime.Text = "A megadott időben " + startTime.ToString("yyyy-MM-dd") + " - " + endTime.ToString("yyyy-MM-dd") + " a szállás foglalt, kérem válasszon más időpontot!";
                    }
                    else
                    {
                        // foglalás mentése
                        entities.AddToRent(new Rent
                        {
                            CustomerName = (Session["Customer"] as Customer).UserName, // már csak a felhasználónév kell
                            StartDate = _CalendarStartTime.SelectedDate,
                            AppartmentId = Convert.ToInt32(Request["Appartment"]),
                            Weeks = Convert.ToInt32(_TextRentTime.Text)
                        }); // felveszünk egy új foglalást

                        entities.SaveChanges(); // elmentjük a változtatásokat
                        _DivRentMade.Visible = true; // megjelenítjük a foglalás üzenetét
                        _DivRentMade.InnerText = "A foglalás sikerült, köszönjük!"; // beállítjuk a foglalás üzenetét
                    }
                }
                catch
                {
                    _DivRentMade.Visible = true;
                    _DivRentMade.InnerText = "A foglalás sajnos nem sikerült, kérjük vegye fel a kapcsolatot az irodával!";
                }
            }
        }
    }
}