﻿using System;
using System.ComponentModel;
using System.Web.UI;

namespace ELTE.Web.GoogleStaticMap.Control
{
    /// <summary>
    /// Google szín felsorolási típusa.
    /// </summary>
    public enum GoogleColor { Black, Brown, Green, Purple, Yellow, Blue, Gray, Orange, Red, White }

    /// <summary>
    /// Google jelölés típusa.
    /// </summary>
    [Serializable]
    [ToolboxItem(true)]
    [ToolboxData("<{0}:GoogleMarker Latitude=\"\" Longitude=\"\" Label=\"\" Color=\"Red\" runat=\"server\"></{0}:GoogleMarker>")]
    public class GoogleMarker : GoogleCoordinate // speciális koordináta
    {
        /// <summary>
        /// Jelölés színének lekérdezése, vagy beállítása.
        /// </summary>
        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("Red")]
        [Localizable(false)]
        public GoogleColor Color { get; set; }

        /// <summary>
        /// Jelölés címkéjének lekérdezése, vagy beállítása.
        /// </summary>
        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("")]
        [Localizable(false)]
        public Char? Label { get; set; } // a címke nem kötelező

        public GoogleMarker() {}
        public GoogleMarker(Double latitude, Double longitude, GoogleColor color) : base(latitude, longitude)
        {
            Color = color;
        }
        public GoogleMarker(Double latitude, Double longitude, GoogleColor color, Char label) : this(latitude, longitude, color)
        {
            Label = label;
        }

        public override String ToString()
        {
            String marker = base.ToString() + "," + Color.ToString().ToLower();
            if (Label != null) marker += Label.ToString().ToLower(); // ha van címke
            return marker;
        }
    }
}
