﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Web.UI;

namespace ELTE.Web.GoogleStaticMap.Control
{
    /// <summary>
    /// Google útvonal típusa.
    /// </summary>
    [Serializable]
    [ToolboxItem(true)]
    [ToolboxData("<{0}:GooglePath runat=\"server\"></{0}:GooglePath>")]
    public class GooglePath
    {
        private List<GoogleCoordinate> _Points;

        /// <summary>
        /// Útvonal színének lekérdezése, vagy beállítása.
        /// </summary>
        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("Blue")]
        [Localizable(false)]
        public Color Color { get; set; }

        /// <summary>
        /// Útvonal vastagságának lekérdezése, vagy beállítása.
        /// </summary>
        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("1")]
        [Localizable(false)]
        public Int32 Weight { get; set; }

        /// <summary>
        /// Útvonal pontjainak lekérdezése, vagy beállítása.
        /// </summary>
        [
        DesignerSerializationVisibility(DesignerSerializationVisibility.Content),
        PersistenceMode(PersistenceMode.InnerDefaultProperty),
        Editor(typeof(List<GoogleCoordinate>), typeof(System.Drawing.Design.UITypeEditor)),
        ]
        public List<GoogleCoordinate> Points
        {
            get { return _Points; }
        }

        public GooglePath() { _Points = new List<GoogleCoordinate>(); Color = Color.Blue; Weight = 1; }
        public GooglePath(Color color) { _Points = new List<GoogleCoordinate>(); Color = color; Weight = 1; }
        public GooglePath(Color color, Int32 weight) { _Points = new List<GoogleCoordinate>(); Color = color; Weight = weight; }

        public override String ToString()
        {
            String serializedPath = String.Format("path=rgb:0x{0},weight:{1}|", String.Format("{0:x8}", Color.ToArgb()).Substring(2, 6), Weight);

            List<String> serializedPoints = new List<String>();
            foreach (GoogleCoordinate coordinate in Points)
            {
                serializedPoints.Add(coordinate.ToString());
            }

            return serializedPath + String.Join("|", serializedPoints.ToArray());
        }
    }
}
