IF DB_ID('ELearning') IS NOT NULL
	DROP DATABASE ELearning;
GO

CREATE DATABASE ELearning;
GO
USE ELearning;
GO

CREATE TABLE EUser(
	UserName VARCHAR(12) PRIMARY KEY,
	UserPass BINARY(20) NOT NULL,
	Email VARCHAR(50) UNIQUE NOT NULL, 
	Credits INTEGER NOT NULL,
	IsAdmin TINYINT NOT NULL
);

CREATE TABLE ECourse(
	Id VARCHAR(10) PRIMARY KEY,
	CourseName VARCHAR(100) UNIQUE NOT NULL,
	CourseDescription TEXT NOT NULL
);

CREATE TABLE ELecture(
	Id INTEGER PRIMARY KEY IDENTITY(1,1),
	CourseId VARCHAR(10) NOT NULL,
	LectureName VARCHAR(50) NOT NULL,
	LectureDescription TEXT,
	LecturePrice INTEGER NOT NULL
	CONSTRAINT LectureToCourse
        FOREIGN KEY (CourseId)
        REFERENCES ECourse (Id)
);

CREATE TABLE ELectureContent(
	ContentId INTEGER PRIMARY KEY IDENTITY(1,1),
	LectureId INTEGER UNIQUE NOT NULL,
	Content VARBINARY(max),
	CONSTRAINT ContentToLecture
        FOREIGN KEY (LectureId) 
        REFERENCES ELecture (Id)
);

CREATE TABLE ELectureImage(
	ImageId INTEGER PRIMARY KEY IDENTITY(1,1),
	LectureId INTEGER NOT NULL,
	ImageSmall VARBINARY(max) NOT NULL,
	ImageLarge VARBINARY(max) NOT NULL,
	CONSTRAINT ImageToLecture
        FOREIGN KEY (LectureId) 
        REFERENCES ELecture (Id)
);

CREATE TABLE UserLog(
	Id INTEGER PRIMARY KEY IDENTITY(1,1),
	LogTime DATETIME NOT NULL,
	UserName VARCHAR(12) NOT NULL,
	LogType VARCHAR(20) NOT NULL,
	LogMessage TEXT,
	CONSTRAINT LogToUser
        FOREIGN KEY (UserName) 
        REFERENCES EUser (UserName)
);
GO

INSERT INTO ECourse (Id, CourseName, CourseDescription) VALUES ('EVA1','Esemnyvezrelt alkalmazsok fejlesztse I','Grafikus felhasznli felletet hasznl (GUI), prbeszd alap, esemnyvezrelt, tbb rteg alkalmazsok ksztse. A hallgatk Windows-os s Linux-os krnyezetben is ksztenek alkalmazsokat, gy lehetsgk van a klnbz fejleszti technikk elsajttsra s egy ltalnosabb kp kialaktsra. A hallgatk a C++-ra tmaszkod programknyvtr (Qt) mellett egy msik programozsi nyelvvel (C#) is megismerkedhetnek, s azok interaktv programksztsi lehetsgeikkel.Fejleszteszkzknt Windows alatt Microsoft Visual Studio-t, illetve Linux alatt a Qt Creator fejlesztkrnyezeteket hasznljuk.');
INSERT INTO ECourse (Id, CourseName, CourseDescription) VALUES ('EVA2','Esemnyvezrelt alkalmazsok fejlesztse II','A kurzus clja adatbzis szerverre pl s korszer grafikus felhasznli fellettel rendelkez, nagyobb mret alkalmazsok fejlesztsnek elsajttsa. A hallgatk ismtelten Windows s Linux krnyezet alatt is megismerkedhetnek SQL alap adatbzis-kezelkkel, s kszthetnek sszetett, tbbrteg alkalmazsokat C# s C++/Qt krnyezetek segtsgvel, valamint betekintst kapnak a nyelvbe integrlt lekrdezs alap technolgikba (LINQ).');
INSERT INTO ECourse (Id, CourseName, CourseDescription) VALUES ('NET1','Programozs .NET krnyezetben','A hallgatk a flv sorn elsajtthatjk a .NET keretrendszer, valamint a C# programozsi nyelv mkdsi s felptsi elveit rszletes betekintst nyerhetnek a nyelv lehetsgeibe, s megismerkedhetnek a hozz kapcsold alapvet technolgikkal. A flv vgre a hallgatk egy tfog kpet kapnak a keretrendszer hasznlatrl, valamint a C# programozsi nyelvrl.');
INSERT INTO ECourse (Id, CourseName, CourseDescription) VALUES ('NET2','Halad .NET programozs','A kurzus clja a korbbi flv ismereteire alapozva a .NET keretrendszer 4-es vltozatnak elsajttsa, klns tekintettel a 2D s 3D grafika, adatkezels, hlzati, szerver s kliens oldali webes, valamint mobil fejlesztsi terletekre (ASP.NET, WPF, WCF, LINQ, Entity Framework, Silverlight technolgik segtsgvel). A flv sorn a hallgatknak lehetsge lesz csoportban trtn alkalmazsfejlesztsre, s gy sszetett alkalmazsrendszerek megvalstsra.');
GO