﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Security;
using ELearning.Models;
using ELearning.Models.Exceptions;

namespace ELearning.Controllers
{
    /// <summary>
    /// Felhasználókezelés vezérlői
    /// </summary>
    [HandleError(View = "Error")]
    public class AuthController : Controller
    {
        /// <summary>
        /// Bejelentkezési oldal
        /// </summary>
        /// <returns>Állapottól függő céloldal</returns>
        public ActionResult Index()
        {
            if (User.Identity.IsAuthenticated)
                return RedirectToAction("Index", "Course");
            else
                return RedirectToAction("LogOn", new { returnUrl = Request.Url.PathAndQuery });
        }

        /// <summary>
        /// Bejelentkezés
        /// </summary>
        /// <returns>Bejelentkezési nézet</returns>
        public ActionResult LogOn()
        {
            return View();
        }

        /// <summary>
        /// Bejelentkezés feldolgozás
        /// </summary>
        /// <param name="model">Bejelentkezési adatok modellje</param>
        /// <param name="returnUrl">Visszatérési URL</param>
        /// <returns>Bejelentkezési nézet vagy a céloldal</returns>
        [HttpPost]
        public ActionResult LogOn(LogOnViewModel model, String returnUrl)
        {
            if (ModelState.IsValid)
            {
                try
                {
                    Session["User"] = DataManager.LogOnUser(model.UserName, model.UserPass);
                    FormsAuthentication.SetAuthCookie(model.UserName, true);
                    if (!String.IsNullOrEmpty(returnUrl))
                        return Redirect(returnUrl);
                    else
                        return RedirectToAction("Index", "Course");
                }
                catch (UserNameNotExitsException)
                {
                    ModelState.AddModelError("UserName", "Hibás azonosító.");
                }
                catch (UserPassWrongException)
                {
                    ModelState.AddModelError("UserPass", "Hibás jelszó.");
                }
            }
            return View(model);
        }

        /// <summary>
        /// Kijelentkezés
        /// </summary>
        /// <returns>Kurzuslista nézet</returns>
        [Authorize]
        public ActionResult LogOff()
        {
            FormsAuthentication.SignOut();
            Session.Remove("User");
            return RedirectToAction("Index", "Course");
        }

        /// <summary>
        /// Regisztráció
        /// </summary>
        /// <returns>Regisztrációs nézet</returns>
        public ActionResult Register()
        {
            return View();
        }

        /// <summary>
        /// Regisztráció feldolgozása
        /// </summary>
        /// <param name="model">Regisztrációs adatok modellje</param>
        /// <returns>Regisztrációs nézet vagy a céloldal</returns>
        [HttpPost]
        public ActionResult Register(RegisterViewModel model)
        {
            if (ModelState.IsValid)
            {
                if (model.UserPass == model.ConfirmPass)
                {
                    EUser user = new EUser
                    {
                        UserName = model.UserName,
                        Email = model.Email,
                        Credits = 100,
                        IsAdmin = 0
                    };

                    try
                    {
                        Session["User"] = DataManager.RegisterUser(user, model.UserPass);
                        FormsAuthentication.SetAuthCookie(model.UserName, true);
                        return RedirectToAction("Index", "Course");
                    }
                    catch (UserNameDuplicationException)
                    {
                        ModelState.AddModelError("UserName", "Hibás azonosító.");
                    }
                }
                else
                    ModelState.AddModelError("", "A megadott két jelszó nem egyezik.");
            }
            return View(model);
        }
    }
}
