﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using ELearning.Models;
using System.Drawing;

namespace ELearning.Controllers
{
    /// <summary>
    /// Kurzusok vezérlői
    /// </summary>
    [HandleError(View = "Error")]
    public class CourseController : Controller
    {
        /// <summary>
        /// Kurzusok listája
        /// </summary>
        /// <returns>Kurzuslista nézet</returns>
        public ActionResult Index()
        {
            return View(DataManager.GetAllCourses());
        }

        /// <summary>
        /// Tananyag létrehozása
        /// </summary>
        /// <returns>Tananyag létrehozási nézet</returns>
        [Authorize]
        public ActionResult Create()
        {
            EUser user = (EUser)Session["User"];
            if (user.IsAdmin == 1)
            {
                LectureViewModel model = new LectureViewModel();
                model.Credit = 10;
                model.Courses = DataManager.GetAllCourses();
                return View(model);
            }
            else
                return View("Denied");
        }

        /// <summary>
        /// Tananyag létrehozása
        /// </summary>
        /// <param name="model">Tananyag modell</param>
        /// <returns>Tananyag létrehozási nézet vagy céloldal</returns>
        [Authorize]
        [HttpPost]
        public ActionResult Create(LectureViewModel model)
        {
            EUser user = (EUser)Session["User"];
            if (user.IsAdmin == 1)
            {
                model.Courses = DataManager.GetAllCourses();
                if (ModelState.IsValid)
                {
                    if (model.File.ContentType == "application/zip"
                        || model.File.ContentType == "application/x-zip"
                        || model.File.ContentType == "application/x-zip-compressed")
                    {
                        Session["lectureId"] = DataManager.CreateLecture(model, user);
                        return RedirectToAction("AddImage");
                    }
                    else
                        ModelState.AddModelError("File", "Nem ZIP fájlt töltöttél fel!");
                }
                return View(model);
            }
            else
                return View("Denied");
        }

        /// <summary>
        /// Előnézeti kép hozzáadása
        /// </summary>
        /// <returns>Előnézeti kép hozzáadása nézet</returns>
        [Authorize]
        public ActionResult AddImage()
        {
            if (Session["lectureId"] != null)
            {
                ImageViewModel model = new ImageViewModel();
                return View(model);
            }
            else
                return View("Denied");
        }

        /// <summary>
        /// Előnézeti kép hozzáadása
        /// </summary>
        /// <param name="model">Előnézeti kép modell</param>
        /// <param name="finishButton">Befejezés gomb</param>
        /// <returns>Előnézeti kép hozzáadása nézet vagy céloldal</returns>
        [Authorize]
        [HttpPost]
        public ActionResult AddImage(ImageViewModel model, String finishButton)
        {
            if (finishButton != null)
            {
                Session.Remove("lectureId");
                return RedirectToAction("Index");
            }

            if (Session["lectureId"] != null)
            {
                if (ModelState.IsValid)
                {
                    if (model.Image.ContentType.Contains("image"))
                    {
                        try
                        {
                            Image image = Image.FromStream(model.Image.InputStream);
                            DataManager.AddLectureImage((ELecture)Session["lectureId"], image, (EUser)Session["User"]);
                            ImageViewModel newModel = new ImageViewModel();
                            newModel.PreviousSuccess = true;
                            return View(newModel);
                        }
                        catch (ArgumentException)
                        {
                            ModelState.AddModelError("Image", "Nem képfájlt töltöttél fel!");
                        }
                    }
                    else
                        ModelState.AddModelError("Image", "Nem képfájlt töltöttél fel!");
                }
                return View(model);
            }
            else
                return View("Denied");
        }

        /// <summary>
        /// Kicsinyített kép megtekintése
        /// </summary>
        /// <param name="id">Kép azonosító</param>
        /// <returns>Kicsinyített kép</returns>
        public ActionResult SmallImage(Int32 id)
        {
            ELectureImage image= DataManager.GetLectureImage(id);
            return File(image.ImageSmall, "image/png");

        }

        /// <summary>
        /// Eredeti kép megtekintése
        /// </summary>
        /// <param name="id">Kép azonosító</param>
        /// <returns>Eredeti kép</returns>
        public ActionResult LargeImage(Int32 id)
        {
            ELectureImage image = DataManager.GetLectureImage(id);
            return File(image.ImageLarge, "image/png");
        }

        /// <summary>
        /// Tananyag letöltése
        /// </summary>
        /// <param name="id">Tananyag azonosító</param>
        /// <returns>Tananyag</returns>
        public ActionResult Download(Int32 id)
        {
            ELectureContent content = DataManager.GetLectureContent(id, (EUser)Session["User"]);
            return File(content.Content, "application/zip", String.Format("{0}-{1}.zip", content.ELecture.LectureName, content.ContentId));
        }
    }
}
