IF DB_ID('TravelAgency_3') IS NOT NULL
	DROP DATABASE TravelAgency_3;
GO
	
CREATE DATABASE TravelAgency_3;
GO
USE TravelAgency_3;
GO

CREATE TABLE City(
    Id INTEGER PRIMARY KEY IDENTITY(1,1),
    Name VARCHAR(40)
);
GO

CREATE TABLE Building (
    Id INTEGER PRIMARY KEY IDENTITY(1,1),
    Name VARCHAR(30),
    CityId INTEGER NOT NULL,
    SeaDistance INTEGER,
    ShoreId INTEGER,
    Comment VARCHAR(1000),
    LocationX FLOAT NOT NULL,
    LocationY FLOAT NOT NULL,
    CONSTRAINT BuldingToCity 
        FOREIGN KEY (CityId) 
        REFERENCES City (Id)
);
GO

CREATE TABLE BuildingImage
(
	Id INTEGER PRIMARY KEY IDENTITY(1,1),
	BuildingId INTEGER NOT NULL,
	ImageSmall VARBINARY(max) NOT NULL,
	ImageLarge VARBINARY(max) NOT NULL
	CONSTRAINT ImageToBuilding 
        FOREIGN KEY (BuildingId) 
        REFERENCES Building (Id)
)

CREATE TABLE Appartment (
    Id INTEGER PRIMARY KEY IDENTITY(1,1),
    BuildingId INTEGER NOT NULL,
    Number INTEGER,
    Room INTEGER,
    Turnday INTEGER,
    Comment VARCHAR(1000),
    Price INTEGER,
    CONSTRAINT AppartmentToBuilding 
        FOREIGN KEY (BuildingId) 
        REFERENCES Building (Id)
);
GO

CREATE TABLE Rent (
    Id INTEGER PRIMARY KEY IDENTITY(1,1),
    Name VARCHAR(40),
    Address VARCHAR(200),
    PhoneNumber VARCHAR(20),
    Email VARCHAR(100),
    AppartmentId INTEGER,
    StartDate Date,
    Weeks INTEGER,
    CONSTRAINT RentToAppartement 
        FOREIGN KEY (AppartmentId) 
        REFERENCES Appartment (Id),        
);
GO

INSERT INTO City VALUES('Cavallino');
INSERT INTO City VALUES('Lido di Jesolo');

INSERT INTO Building VALUES('Petra bungal', 1, 100, 0, 'Szlls bungallban 100m strandtl (homokos tengerpart). A terleten tallhat tterem, br, jtsztr. lyszakai nyugalmat betartani. Ott-tartzkods szombattl szombatig. A szllsszolgltat beszl is csehl. Parkol - nem rztt, ingyenes. Busz 100m. Vonat (lloms San Dona di Piave) 25km. Repltr (Venezia - Marco Polo) 40km. Cavallino - kzpont.', 45.4591, 12.5068);
INSERT INTO Building VALUES('Willerby bungal', 1, 100, 0, 'Szlls bungallban 100m strandtl (homokos tengerpart). A terleten tallhat tterem, br, jtsztr. lyszakai nyugalmat betartani. Ott-tartzkods szombattl szombatig. A szllsszolgltat beszl is csehl. Parkol - nem rztt, ingyenes. Busz 100m. Vonat (lloms San Dona di Piave) 25km. Repltr (Venezia - Marco Polo) 40km. Cavallino - kzpont.', 45.4566, 12.5004);
INSERT INTO Building VALUES('Cavallino Hotel', 1, 50, 0, 'Szlloda kzsgben 50m a tengertl. A hotelban / terletn tallhat tterem, terasz, br, kvhz, trsalg TV-vel, bilird, darts, szauna, nyri medence, kerti pihenhely, homokoz, hinta, lgkondicionl; illetk fejben: sportfelszerels-klcsnz, lovagls, pnzvlt. Internet-csatlakozs. Naperny s napozgy a szlls rban. Parkol - nem rztt, ingyenes. Busz 20m. Repltr (Aeroporto Marco Polo Venezia) 30km. Cavallino - kzpont 100m.', 45.4788, 12.5677);
INSERT INTO Building VALUES('Hotel Veneto', 2, 2000, 0, 'Szlloda kzsgben, 2km strandtl. A hotelban van tkezde (csak reggeli), kerkprklcsnz. A szllodban nincs tterem, individulis tkezs tteremben 500m a hoteltl. Internet-csatlakozs Wi-Fi s lgkondicionl illetk fejben. Parkol - nem rztt, ingyenes. Busz 500m. Vonat (lloms Venezia) 25km. Lido di Jesolo - kzpont 6km.', 45.5171, 12.6694);

INSERT INTO Appartment VALUES(1, 1, 4, 6, '2x2-gyas szoba, nappali kt ptggyal (sztnyithat hever), frdszoba zuhanyozflkvel s WC-vel, konyha (gztzhely, htszekrny), tkezsarok.', 21);
INSERT INTO Appartment VALUES(1, 2, 4, 6, '2x2-gyas szoba, nappali kt ptggyal (sztnyithat hever), frdszoba zuhanyozflkvel s WC-vel, konyha (gztzhely, htszekrny), tkezsarok.', 21);
INSERT INTO Appartment VALUES(1, 3, 4, 6, '2x2-gyas szoba, nappali kt ptggyal (sztnyithat hever), frdszoba zuhanyozflkvel s WC-vel, konyha (gztzhely, htszekrny), tkezsarok.', 21);
INSERT INTO Appartment VALUES(1, 4, 4, 6, '2x2-gyas szoba, nappali kt ptggyal (sztnyithat hever), frdszoba zuhanyozflkvel s WC-vel, konyha (gztzhely, htszekrny), tkezsarok.', 21);
INSERT INTO Appartment VALUES(2, 1, 4, 6, '2x2-gyas szoba, TV, nappali kt ptggyal, frdszoba zuhanyozflkvel s WC-vel, konyha (gztzhely, htszekrny), tkezsarok.', 28);
INSERT INTO Appartment VALUES(2, 2, 4, 6, '2x2-gyas szoba, TV, nappali kt ptggyal, frdszoba zuhanyozflkvel s WC-vel, konyha (gztzhely, htszekrny), tkezsarok.', 28);
INSERT INTO Appartment VALUES(2, 3, 4, 6, '2x2-gyas szoba, TV, nappali kt ptggyal, frdszoba zuhanyozflkvel s WC-vel, konyha (gztzhely, htszekrny), tkezsarok.', 28);
INSERT INTO Appartment VALUES(3, 1, 1, 7, '1-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 18);
INSERT INTO Appartment VALUES(3, 2, 1, 7, '1-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 18);
INSERT INTO Appartment VALUES(3, 3, 1, 7, '1-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 18);
INSERT INTO Appartment VALUES(3, 4, 2, 7, '2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 32);
INSERT INTO Appartment VALUES(3, 5, 2, 7, '2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 32);
INSERT INTO Appartment VALUES(3, 6, 2, 7, '2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 32);
INSERT INTO Appartment VALUES(3, 7, 2, 7, '2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 32);
INSERT INTO Appartment VALUES(3, 8, 2, 7, '2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 32);
INSERT INTO Appartment VALUES(3, 9, 2, 7, '2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, hajszrt, telefon, erkly, mholdas TV.', 32);
INSERT INTO Appartment VALUES(3, 10, 4, 7, 'Apartman: 2x2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, telefon, erkly, mholdas TV, nappali, kis konyha.', 54);
INSERT INTO Appartment VALUES(3, 11, 4, 7, 'Apartman: 2x2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, telefon, erkly, mholdas TV, nappali, kis konyha.', 54);
INSERT INTO Appartment VALUES(3, 12, 4, 7, 'Apartman: 2x2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, telefon, erkly, mholdas TV, nappali, kis konyha.', 54);
INSERT INTO Appartment VALUES(3, 13, 4, 7, 'Apartman: 2x2-gyas szoba, frdszoba zuhanyozflkvel s WC-vel, telefon, erkly, mholdas TV, nappali, kis konyha.', 54);
INSERT INTO Appartment VALUES(4, 1, 3, 6, '3-gyas szoba lehetsg ptgyra, TV, frdszoba (zuhanyozflke, WC, bid), erkly.', 65);
INSERT INTO Appartment VALUES(4, 2, 2, 6, '2-gyas szoba kt ptggyal, TV, frdszoba (zuhanyozflke, WC, bid), erkly.', 42);
INSERT INTO Appartment VALUES(4, 3, 2, 6, '2-gyas szoba kt ptggyal, TV, frdszoba (zuhanyozflke, WC, bid), erkly.', 42);
INSERT INTO Appartment VALUES(4, 4, 2, 6, '2-gyas szoba kt ptggyal, TV, frdszoba (zuhanyozflke, WC, bid), erkly.', 42);
INSERT INTO Appartment VALUES(4, 5, 2, 6, '2-gyas szoba kt ptggyal, TV, frdszoba (zuhanyozflke, WC, bid), erkly.', 42);
INSERT INTO Appartment VALUES(4, 6, 2, 6, '2-gyas szoba, TV, frdszoba (zuhanyozflke, WC, bid), erkly.', 34);
INSERT INTO Appartment VALUES(4, 7, 2, 6, '2-gyas szoba, TV, frdszoba (zuhanyozflke, WC, bid), erkly.', 34);
GO


